Register

Enum Register 

#[repr(u8)]
pub enum Register {
Show 14 variants PowerControl = 0, Reset = 1, FrameRate = 2, InterruptControl = 3, Status = 4, StatusClear = 5, Average = 7, AverageData = 31, InterruptLevelHighLower = 8, InterruptLevelLowLower = 10, InterruptHysteresisLower = 12, ThermistorLower = 14, InterruptTableStart = 16, PixelTemperatureStart = 128,
}
The registers used to access the Grid-EYE.

Variants



PowerControl = 0

See PowerControlValue for details on values Read/write.



Reset = 1

See ResetValue for details on values. Write-only.



FrameRate = 2

See FrameRateValue for details on values. Read/write.



InterruptControl = 3

See InterruptControlValue for details on values. Read/write.



Status = 4

The status flags for the device. The flags will remain set until cleared by writing to [StatusClear]. Read-only.



StatusClear = 5

Clear one or both of the status flags for the device. Write-only.



Average = 7

Whether or not the pixel values should be overaged or not. Read/write.



AverageData = 31

A semi-documented register that is written to when changing the moving average mode. Write-only.



InterruptLevelHighLower = 8

The upper temperature limit for triggering an interrupt. This is in the pixel temperature format. Read/write.



InterruptLevelLowLower = 10

The lower temperature limit for triggering an interrupt. This is in the pixel temperature format. Read/write.



InterruptHysteresisLower = 12

The hysteresis limit for triggering an interrupt. The datasheet isn’t very clear as to how this value is used. This is in the pixel temperature format. Read/write.



ThermistorLower = 14

The sensor has an on-board thermistor useful for for calibrating the output of the camera. This is in the thermistor temperature format. Read-only.



InterruptTableStart = 16

The first register of the interrupt table. It continues up through 0x17 with each register representing a bitfield of whether or not that pixel in the image has triggered an interrupt. The first bit of the first register is pixel 1, with the rest of the pixels following in order from there (see identifying pixels). Read-only.



PixelTemperatureStart = 128

The lower bits of the temperature of pixel 1. The upper bits are in the register following this one, with the lower bits for pixel 2 after that and so on up through 0xFF. This is in the pixel temperature format.